@@ -20,6 +20,7 @@
 #ifndef _LOG_H_
 #define _LOG_H_
 
+#include <cstdio>
 #include <string>
 #include <boost/asio/ip/tcp.hpp>
 
@@ -42,6 +43,9 @@ public:
     static void log_with_date_time(const std::string &message, Level level = ALL);
     static void log_with_endpoint(const boost::asio::ip::tcp::endpoint &endpoint, const std::string &message, Level level = ALL);
     static void redirect(const std::string &filename);
+    static void reset();
+private:
+    static FILE *output_stream;
 };
 
 #endif // _LOG_H_
